easm

package module
v0.0.0-...-fc6d6d1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LabelByWorkspace

type LabelByWorkspace struct {
	pulumi.CustomResourceState

	// Label color.
	Color pulumi.StringPtrOutput `pulumi:"color"`
	// Label display name.
	DisplayName pulumi.StringPtrOutput `pulumi:"displayName"`
	// The name of the resource
	Name pulumi.StringOutput `pulumi:"name"`
	// Resource provisioning state.
	ProvisioningState pulumi.StringOutput `pulumi:"provisioningState"`
	// Azure Resource Manager metadata containing createdBy and modifiedBy information.
	SystemData SystemDataResponseOutput `pulumi:"systemData"`
	// The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
	Type pulumi.StringOutput `pulumi:"type"`
}

Label details Azure REST API version: 2023-04-01-preview. Prior API version in Azure Native 1.x: 2022-04-01-preview.

func GetLabelByWorkspace

func GetLabelByWorkspace(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *LabelByWorkspaceState, opts ...pulumi.ResourceOption) (*LabelByWorkspace, error)

GetLabelByWorkspace gets an existing LabelByWorkspace resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewLabelByWorkspace

func NewLabelByWorkspace(ctx *pulumi.Context,
	name string, args *LabelByWorkspaceArgs, opts ...pulumi.ResourceOption) (*LabelByWorkspace, error)

NewLabelByWorkspace registers a new resource with the given unique name, arguments, and options.

func (*LabelByWorkspace) ElementType

func (*LabelByWorkspace) ElementType() reflect.Type

func (*LabelByWorkspace) ToLabelByWorkspaceOutput

func (i *LabelByWorkspace) ToLabelByWorkspaceOutput() LabelByWorkspaceOutput

func (*LabelByWorkspace) ToLabelByWorkspaceOutputWithContext

func (i *LabelByWorkspace) ToLabelByWorkspaceOutputWithContext(ctx context.Context) LabelByWorkspaceOutput

type LabelByWorkspaceArgs

type LabelByWorkspaceArgs struct {
	// Label color.
	Color pulumi.StringPtrInput
	// Label display name.
	DisplayName pulumi.StringPtrInput
	// The name of the Label.
	LabelName pulumi.StringPtrInput
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName pulumi.StringInput
	// The name of the Workspace.
	WorkspaceName pulumi.StringInput
}

The set of arguments for constructing a LabelByWorkspace resource.

func (LabelByWorkspaceArgs) ElementType

func (LabelByWorkspaceArgs) ElementType() reflect.Type

type LabelByWorkspaceInput

type LabelByWorkspaceInput interface {
	pulumi.Input

	ToLabelByWorkspaceOutput() LabelByWorkspaceOutput
	ToLabelByWorkspaceOutputWithContext(ctx context.Context) LabelByWorkspaceOutput
}

type LabelByWorkspaceOutput

type LabelByWorkspaceOutput struct{ *pulumi.OutputState }

func (LabelByWorkspaceOutput) Color

Label color.

func (LabelByWorkspaceOutput) DisplayName

Label display name.

func (LabelByWorkspaceOutput) ElementType

func (LabelByWorkspaceOutput) ElementType() reflect.Type

func (LabelByWorkspaceOutput) Name

The name of the resource

func (LabelByWorkspaceOutput) ProvisioningState

func (o LabelByWorkspaceOutput) ProvisioningState() pulumi.StringOutput

Resource provisioning state.

func (LabelByWorkspaceOutput) SystemData

Azure Resource Manager metadata containing createdBy and modifiedBy information.

func (LabelByWorkspaceOutput) ToLabelByWorkspaceOutput

func (o LabelByWorkspaceOutput) ToLabelByWorkspaceOutput() LabelByWorkspaceOutput

func (LabelByWorkspaceOutput) ToLabelByWorkspaceOutputWithContext

func (o LabelByWorkspaceOutput) ToLabelByWorkspaceOutputWithContext(ctx context.Context) LabelByWorkspaceOutput

func (LabelByWorkspaceOutput) Type

The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"

type LabelByWorkspaceState

type LabelByWorkspaceState struct {
}

func (LabelByWorkspaceState) ElementType

func (LabelByWorkspaceState) ElementType() reflect.Type

type LookupLabelByWorkspaceArgs

type LookupLabelByWorkspaceArgs struct {
	// The name of the Label.
	LabelName string `pulumi:"labelName"`
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName string `pulumi:"resourceGroupName"`
	// The name of the Workspace.
	WorkspaceName string `pulumi:"workspaceName"`
}

type LookupLabelByWorkspaceOutputArgs

type LookupLabelByWorkspaceOutputArgs struct {
	// The name of the Label.
	LabelName pulumi.StringInput `pulumi:"labelName"`
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName pulumi.StringInput `pulumi:"resourceGroupName"`
	// The name of the Workspace.
	WorkspaceName pulumi.StringInput `pulumi:"workspaceName"`
}

func (LookupLabelByWorkspaceOutputArgs) ElementType

type LookupLabelByWorkspaceResult

type LookupLabelByWorkspaceResult struct {
	// Label color.
	Color *string `pulumi:"color"`
	// Label display name.
	DisplayName *string `pulumi:"displayName"`
	// Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
	Id string `pulumi:"id"`
	// The name of the resource
	Name string `pulumi:"name"`
	// Resource provisioning state.
	ProvisioningState string `pulumi:"provisioningState"`
	// Azure Resource Manager metadata containing createdBy and modifiedBy information.
	SystemData SystemDataResponse `pulumi:"systemData"`
	// The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
	Type string `pulumi:"type"`
}

Label details

func LookupLabelByWorkspace

func LookupLabelByWorkspace(ctx *pulumi.Context, args *LookupLabelByWorkspaceArgs, opts ...pulumi.InvokeOption) (*LookupLabelByWorkspaceResult, error)

Returns a label in the given workspace. Azure REST API version: 2023-04-01-preview.

type LookupLabelByWorkspaceResultOutput

type LookupLabelByWorkspaceResultOutput struct{ *pulumi.OutputState }

Label details

func (LookupLabelByWorkspaceResultOutput) Color

Label color.

func (LookupLabelByWorkspaceResultOutput) DisplayName

Label display name.

func (LookupLabelByWorkspaceResultOutput) ElementType

func (LookupLabelByWorkspaceResultOutput) Id

Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}

func (LookupLabelByWorkspaceResultOutput) Name

The name of the resource

func (LookupLabelByWorkspaceResultOutput) ProvisioningState

Resource provisioning state.

func (LookupLabelByWorkspaceResultOutput) SystemData

Azure Resource Manager metadata containing createdBy and modifiedBy information.

func (LookupLabelByWorkspaceResultOutput) ToLookupLabelByWorkspaceResultOutput

func (o LookupLabelByWorkspaceResultOutput) ToLookupLabelByWorkspaceResultOutput() LookupLabelByWorkspaceResultOutput

func (LookupLabelByWorkspaceResultOutput) ToLookupLabelByWorkspaceResultOutputWithContext

func (o LookupLabelByWorkspaceResultOutput) ToLookupLabelByWorkspaceResultOutputWithContext(ctx context.Context) LookupLabelByWorkspaceResultOutput

func (LookupLabelByWorkspaceResultOutput) Type

The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"

type LookupWorkspaceArgs

type LookupWorkspaceArgs struct {
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName string `pulumi:"resourceGroupName"`
	// The name of the Workspace.
	WorkspaceName string `pulumi:"workspaceName"`
}

type LookupWorkspaceOutputArgs

type LookupWorkspaceOutputArgs struct {
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName pulumi.StringInput `pulumi:"resourceGroupName"`
	// The name of the Workspace.
	WorkspaceName pulumi.StringInput `pulumi:"workspaceName"`
}

func (LookupWorkspaceOutputArgs) ElementType

func (LookupWorkspaceOutputArgs) ElementType() reflect.Type

type LookupWorkspaceResult

type LookupWorkspaceResult struct {
	// Data plane endpoint.
	DataPlaneEndpoint string `pulumi:"dataPlaneEndpoint"`
	// Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
	Id string `pulumi:"id"`
	// The geo-location where the resource lives
	Location string `pulumi:"location"`
	// The name of the resource
	Name string `pulumi:"name"`
	// Resource provisioning state.
	ProvisioningState string `pulumi:"provisioningState"`
	// Azure Resource Manager metadata containing createdBy and modifiedBy information.
	SystemData SystemDataResponse `pulumi:"systemData"`
	// Resource tags.
	Tags map[string]string `pulumi:"tags"`
	// The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
	Type string `pulumi:"type"`
}

Workspace details.

func LookupWorkspace

func LookupWorkspace(ctx *pulumi.Context, args *LookupWorkspaceArgs, opts ...pulumi.InvokeOption) (*LookupWorkspaceResult, error)

Returns a workspace with the given name. Azure REST API version: 2023-04-01-preview.

type LookupWorkspaceResultOutput

type LookupWorkspaceResultOutput struct{ *pulumi.OutputState }

Workspace details.

func (LookupWorkspaceResultOutput) DataPlaneEndpoint

func (o LookupWorkspaceResultOutput) DataPlaneEndpoint() pulumi.StringOutput

Data plane endpoint.

func (LookupWorkspaceResultOutput) ElementType

func (LookupWorkspaceResultOutput) Id

Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}

func (LookupWorkspaceResultOutput) Location

The geo-location where the resource lives

func (LookupWorkspaceResultOutput) Name

The name of the resource

func (LookupWorkspaceResultOutput) ProvisioningState

func (o LookupWorkspaceResultOutput) ProvisioningState() pulumi.StringOutput

Resource provisioning state.

func (LookupWorkspaceResultOutput) SystemData

Azure Resource Manager metadata containing createdBy and modifiedBy information.

func (LookupWorkspaceResultOutput) Tags

Resource tags.

func (LookupWorkspaceResultOutput) ToLookupWorkspaceResultOutput

func (o LookupWorkspaceResultOutput) ToLookupWorkspaceResultOutput() LookupWorkspaceResultOutput

func (LookupWorkspaceResultOutput) ToLookupWorkspaceResultOutputWithContext

func (o LookupWorkspaceResultOutput) ToLookupWorkspaceResultOutputWithContext(ctx context.Context) LookupWorkspaceResultOutput

func (LookupWorkspaceResultOutput) Type

The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"

type SystemDataResponse

type SystemDataResponse struct {
	// The timestamp of resource creation (UTC).
	CreatedAt *string `pulumi:"createdAt"`
	// The identity that created the resource.
	CreatedBy *string `pulumi:"createdBy"`
	// The type of identity that created the resource.
	CreatedByType *string `pulumi:"createdByType"`
	// The timestamp of resource last modification (UTC)
	LastModifiedAt *string `pulumi:"lastModifiedAt"`
	// The identity that last modified the resource.
	LastModifiedBy *string `pulumi:"lastModifiedBy"`
	// The type of identity that last modified the resource.
	LastModifiedByType *string `pulumi:"lastModifiedByType"`
}

Metadata pertaining to creation and last modification of the resource.

type SystemDataResponseOutput

type SystemDataResponseOutput struct{ *pulumi.OutputState }

Metadata pertaining to creation and last modification of the resource.

func (SystemDataResponseOutput) CreatedAt

The timestamp of resource creation (UTC).

func (SystemDataResponseOutput) CreatedBy

The identity that created the resource.

func (SystemDataResponseOutput) CreatedByType

The type of identity that created the resource.

func (SystemDataResponseOutput) ElementType

func (SystemDataResponseOutput) ElementType() reflect.Type

func (SystemDataResponseOutput) LastModifiedAt

func (o SystemDataResponseOutput) LastModifiedAt() pulumi.StringPtrOutput

The timestamp of resource last modification (UTC)

func (SystemDataResponseOutput) LastModifiedBy

func (o SystemDataResponseOutput) LastModifiedBy() pulumi.StringPtrOutput

The identity that last modified the resource.

func (SystemDataResponseOutput) LastModifiedByType

func (o SystemDataResponseOutput) LastModifiedByType() pulumi.StringPtrOutput

The type of identity that last modified the resource.

func (SystemDataResponseOutput) ToSystemDataResponseOutput

func (o SystemDataResponseOutput) ToSystemDataResponseOutput() SystemDataResponseOutput

func (SystemDataResponseOutput) ToSystemDataResponseOutputWithContext

func (o SystemDataResponseOutput) ToSystemDataResponseOutputWithContext(ctx context.Context) SystemDataResponseOutput

type Workspace

type Workspace struct {
	pulumi.CustomResourceState

	// Data plane endpoint.
	DataPlaneEndpoint pulumi.StringOutput `pulumi:"dataPlaneEndpoint"`
	// The geo-location where the resource lives
	Location pulumi.StringOutput `pulumi:"location"`
	// The name of the resource
	Name pulumi.StringOutput `pulumi:"name"`
	// Resource provisioning state.
	ProvisioningState pulumi.StringOutput `pulumi:"provisioningState"`
	// Azure Resource Manager metadata containing createdBy and modifiedBy information.
	SystemData SystemDataResponseOutput `pulumi:"systemData"`
	// Resource tags.
	Tags pulumi.StringMapOutput `pulumi:"tags"`
	// The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
	Type pulumi.StringOutput `pulumi:"type"`
}

Workspace details. Azure REST API version: 2023-04-01-preview. Prior API version in Azure Native 1.x: 2022-04-01-preview.

func GetWorkspace

func GetWorkspace(ctx *pulumi.Context,
	name string, id pulumi.IDInput, state *WorkspaceState, opts ...pulumi.ResourceOption) (*Workspace, error)

GetWorkspace gets an existing Workspace resource's state with the given name, ID, and optional state properties that are used to uniquely qualify the lookup (nil if not required).

func NewWorkspace

func NewWorkspace(ctx *pulumi.Context,
	name string, args *WorkspaceArgs, opts ...pulumi.ResourceOption) (*Workspace, error)

NewWorkspace registers a new resource with the given unique name, arguments, and options.

func (*Workspace) ElementType

func (*Workspace) ElementType() reflect.Type

func (*Workspace) ToWorkspaceOutput

func (i *Workspace) ToWorkspaceOutput() WorkspaceOutput

func (*Workspace) ToWorkspaceOutputWithContext

func (i *Workspace) ToWorkspaceOutputWithContext(ctx context.Context) WorkspaceOutput

type WorkspaceArgs

type WorkspaceArgs struct {
	// The geo-location where the resource lives
	Location pulumi.StringPtrInput
	// The name of the resource group. The name is case insensitive.
	ResourceGroupName pulumi.StringInput
	// Resource tags.
	Tags pulumi.StringMapInput
	// The name of the Workspace.
	WorkspaceName pulumi.StringPtrInput
}

The set of arguments for constructing a Workspace resource.

func (WorkspaceArgs) ElementType

func (WorkspaceArgs) ElementType() reflect.Type

type WorkspaceInput

type WorkspaceInput interface {
	pulumi.Input

	ToWorkspaceOutput() WorkspaceOutput
	ToWorkspaceOutputWithContext(ctx context.Context) WorkspaceOutput
}

type WorkspaceOutput

type WorkspaceOutput struct{ *pulumi.OutputState }

func (WorkspaceOutput) DataPlaneEndpoint

func (o WorkspaceOutput) DataPlaneEndpoint() pulumi.StringOutput

Data plane endpoint.

func (WorkspaceOutput) ElementType

func (WorkspaceOutput) ElementType() reflect.Type

func (WorkspaceOutput) Location

func (o WorkspaceOutput) Location() pulumi.StringOutput

The geo-location where the resource lives

func (WorkspaceOutput) Name

The name of the resource

func (WorkspaceOutput) ProvisioningState

func (o WorkspaceOutput) ProvisioningState() pulumi.StringOutput

Resource provisioning state.

func (WorkspaceOutput) SystemData

Azure Resource Manager metadata containing createdBy and modifiedBy information.

func (WorkspaceOutput) Tags

Resource tags.

func (WorkspaceOutput) ToWorkspaceOutput

func (o WorkspaceOutput) ToWorkspaceOutput() WorkspaceOutput

func (WorkspaceOutput) ToWorkspaceOutputWithContext

func (o WorkspaceOutput) ToWorkspaceOutputWithContext(ctx context.Context) WorkspaceOutput

func (WorkspaceOutput) Type

The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"

type WorkspaceState

type WorkspaceState struct {
}

func (WorkspaceState) ElementType

func (WorkspaceState) ElementType() reflect.Type

Jump to